# ==============================================================================================
# 
# NAME: Opsmgr 2012 Agent Install from Computer List
# 
# AUTHOR: Pete Zerger, MCT, MVP 
# DATE  : 6/23/2012
# 
# COMMENT: This script is designed to discover and install OpsMgr 2012 agents on a list of
#          computers in a text file. Designed to be used with the 'OpsMgr 2012 AD Agent Gap
#          Analysis PowerShell script'at 
#          http://www.systemcentercentral.com/BlogDetails/tabid/143/IndexID/94221/Default.aspx
# ==============================================================================================

#Import PowerShell Modules 
import-module OperationsManager
#import-module ActiveDirectory

#Connect to OpsMgr Management Group
Start-OperationsManagerClientShell -ManagementServerName: "mmsscom01.infrontdemo.local" -PersistConnection: $true -Interactive: $true;

#--------------------------------------------------------------
#OpsMgr Agent Installation Function 
#(We'll call this function later for each computer
# in the list reachable via ping)
#-----------------------------------
Function InstallSCOMAgent {

    param ($TargetAgentList )

$Agents = $TargetAgentList
$PrimaryMgmtServer = Get-SCOMManagementserver -Name mmsscom01.infrontdemo.local
Install-SCOMAgent -Name $Agents -PrimaryManagementServer $PrimaryMgmtServer 

}
 
#---------------------------------------------------------------------
# Ping computers in the AD Agent Gap List to ensure they are available 
#---------------------------------------------------------------------

$list = Import-Csv -Path 'c:\temp\ADAgentGap.csv'

foreach ($entry in $list)
{
    $objComputer = $objResult.Properties;
    # Get the computer ping properties
    $computer = $entry.ServerName

    # Ping the computer
    $pingStatus = Get-WmiObject -Class Win32_PingStatus -Filter "Address = '$computer'";
 
    if($pingStatus.StatusCode -eq 0)
    {
        #If computer is up, write message and launch agent install
        Write-Host -ForegroundColor Green  "Reply received from $computer.";
                InstallSCOMAgent $Computer
    }
    else
    {
        #Else, just write a message indicating computer unreachable 
        Write-Host -ForegroundColor Red "No Reply received from $computer.";
    }
}