@echo off

rem *****************************************************************************************
rem * Batch Script Name:	OpsMgr Backup Automation Example
rem * Written for: 		System Center 2012 Operations Manager Unleashed
rem * Date: 			July, 2012
rem *****************************************************************************************
rem * These scripts are included as an example for automating the OpsMgr 2012 backup process.
rem * NOTE: A full backup of the systems is still required. The script only takes information
rem *       which would not normally be available within a full backup.
rem * 
rem * This script backs up the OpsMgr Server features to the directory specified with the backup variable. 
rem * Set the Server variable to 1 to execute the backup for that role on the server. 
rem * IE: Set the ManagementServer=1 to backup files for the management server role. If all roles exist on one
rem * server all six would be set to 1.
rem * 
rem * Run this batch file on each OpsMgr server role as a scheduled task and then use a backup software solution
rem * to backup the location specified for the backup variable below (defaulted to c:\backup).
rem * 
rem * Required to run this batch job:
rem * Backup directory previously exists (by default: c:\backup) on each server
rem * The following files must be in the backup directory: This script (backup.bat), ExportMP.ps1
rem *
rem * For named instances, fill in the Instance variables which are defined for OpsInstance, DataWareHouseInstance
rem * and ACSInstance starting with the \ character. As an example: set OpsInstance=\Instance1.
rem * 
rem * To backup SRS RDL files, save them to the %SRSexport% directory rather than the default location of My Documents
rem *
rem ****************************************************
rem * Variables - CHANGE HERE
rem ****************************************************
rem *
rem * Recommended enhancements:
rem * 
rem * Backup of created reports if they aren't part of the exported MP items
rem * Auto-detection of the components?
rem * Auto-detection of the database names?
rem *
rem ****************************************************

set password=OpsMgr2012Unleashed
set ManagementServer=1
set OperationsDatabaseServer=0
set DataWarehouseServer=0
set ACSDatabaseServer=0
set SRSServer=0
set WebConsoleServer=0
set backup=c:\backups
set OpsDb=OperationsManager
set OpsInstance=
set DataWarehouseDb=OperationsManagerDW
set DataWarehouseInstance=
set ACSDb=OperationsManagerAC
set ACSInstance=
set SRSInstance=
set SRSexport=c:\exports

goto ManagementServer

:ManagementServer
if "%ManagementServer%"=="0" goto OperationsDatabaseServer
rem ****************************************************
rem * Management Server
rem ****************************************************
echo Management Server
%systemroot%\system32\windowspowershell\v1.0\powershell.exe c:\Backups\exportMP.ps1 -ServerName:%computername%

goto OperationsDatabaseServer

:OperationsDatabaseServer
if "%OperationsDatabaseServer%"=="0" goto DataWarehouseServer
rem ****************************************************
rem * Operations Database Server
rem ****************************************************
echo Operations Database Server
mkdir %Backup%
osql -S %computername%%OpsInstance% -E -Q "BACKUP DATABASE master TO DISK = '%backup%\Ops_master.bak' WITH INIT, NAME = 'master.bak'" 
osql -S %computername%%OpsInstance% -E -Q "BACKUP LOG master with TRUNCATE_ONLY" 
osql -S %computername%%OpsInstance% -E -Q "BACKUP DATABASE MSDB TO DISK = '%backup%\Ops_msdb.bak' WITH INIT, NAME = 'msdb.bak'" 
osql -S %computername%%OpsInstance% -E -Q "BACKUP LOG msdb with TRUNCATE_ONLY" 
osql -S %computername%%OpsInstance% -E -Q "BACKUP DATABASE %OpsDb% TO DISK = '%backup%\%OpsDb%.bak' WITH INIT, NAME = '%OpsDb%.bak'" 
osql -S %computername%%OpsInstance% -E -Q "BACKUP LOG %OpsDb% with TRUNCATE_ONLY" 

:DataWarehouseServer
if "%DataWarehouseServer%"=="0" goto ACSDatabaseServer
rem ****************************************************
rem * Data Warehouse Server
rem ****************************************************
echo Data Warehouse Server
mkdir %Backup%
osql -S %computername%%DataWarehouseInstance% -E -Q "BACKUP DATABASE master TO DISK = '%backup%\DW_master.bak' WITH INIT, NAME = 'master.bak'" 
osql -S %computername%%DataWarehouseInstance% -E -Q "BACKUP LOG master with TRUNCATE_ONLY" 
osql -S %computername%%DataWarehouseInstance% -E -Q "BACKUP DATABASE MSDB TO DISK = '%backup%\DW_msdb.bak' WITH INIT, NAME = 'msdb.bak'" 
osql -S %computername%%DataWarehouseInstance% -E -Q "BACKUP LOG msdb with TRUNCATE_ONLY" 
osql -S %computername%%DataWarehouseInstance% -E -Q "BACKUP DATABASE %DataWarehouseDb% TO DISK = '%backup%\%DataWarehouseDb%.bak' WITH INIT, NAME = '%DataWarehouseDb%.bak'" 
osql -S %computername%%DataWarehouseInstance% -E -Q "BACKUP LOG %DataWarehouseDb% with TRUNCATE_ONLY" 

:ACSDatabaseServer
if "%ACSDatabaseServer%"=="0" goto SRSServer
rem ****************************************************
rem * ACS Database Server
rem ****************************************************
echo ACS Database Server
mkdir %Backup%
osql -S %computername%%ACSInstance% -E -Q "BACKUP DATABASE master TO DISK = '%backup%\ACS_master.bak' WITH INIT, NAME = 'master.bak'" 
osql -S %computername%%ACSInstance% -E -Q "BACKUP LOG master with TRUNCATE_ONLY" 
osql -S %computername%%ACSInstance% -E -Q "BACKUP DATABASE MSDB TO DISK = '%backup%\ACS_msdb.bak' WITH INIT, NAME = 'msdb.bak'" 
osql -S %computername%%ACSInstance% -E -Q "BACKUP LOG msdb with TRUNCATE_ONLY" 
osql -S %computername%%ACSInstance% -E -Q "BACKUP DATABASE %AcsDB% TO DISK = '%backup%\%AcsDB%.bak' WITH INIT, NAME = '%AcsDb%.bak'" 
osql -S %computername%%ACSInstance% -E -Q "BACKUP LOG %AcsDB% with TRUNCATE_ONLY" 

:SRSServer
if "%SRSServer%"=="0" goto WebConsoleServer
rem ****************************************************
rem * SQL Reporting Services Server
rem ****************************************************
mkdir %Backup%
echo SQL Reporting Services Server
osql -S %computername%%SRSInstance% -E -Q "BACKUP DATABASE master TO DISK = '%backup%\SRS_master.bak' WITH INIT, NAME = 'master.bak'" 
osql -S %computername%%SRSInstance% -E -Q "BACKUP LOG master with TRUNCATE_ONLY" 
osql -S %computername%%SRSInstance% -E -Q "BACKUP DATABASE MSDB TO DISK = '%backup%\SRS_msdb.bak' WITH INIT, NAME = 'msdb.bak'" 
osql -S %computername%%SRSInstance% -E -Q "BACKUP LOG msdb with TRUNCATE_ONLY" 
osql -S %computername%%SRSInstance% -E -Q "BACKUP DATABASE reportserver TO DISK = '%backup%\reportserver.bak' WITH INIT, NAME = 'reportserver.bak'" 
osql -S %computername%%SRSInstance% -E -Q "BACKUP LOG reportserver with TRUNCATE_ONLY" 
osql -S %computername%%SRSInstance% -E -Q "BACKUP DATABASE reportservertempdb TO DISK = '%backup%\reportservertempdb.bak' WITH INIT, NAME = 'reportservertempdb.bak'" 
osql -S %computername%%SRSInstance% -E -Q "BACKUP LOG reportservertempdb with TRUNCATE_ONLY" 
rem ** Backup any customized reports extracted to the file system (RDL files)
xcopy %SRSexport%\*.rdl %backup%\
rem ** Export the key file and back it up
echo "y" > %backup%\echoy.txt
rskeymgmt -e -f%backup%\rsdbkey.txt -p%password% < %backup%\echoy.txt

rem ** For security reasons you should keep the rsdbkey.txt file in a secured location **

:WebConsoleServer
if "%WebConsoleServer%"=="0" goto End
rem ****************************************************
rem * Web Console Server
rem ****************************************************
echo Web Console Server
mkdir %Backup%
cd %windir%\system32\inetsrv
appcmd add backup %backup%\IISConfig_backup

:End 
